@@ -3,7 +3,7 @@
 #
 #  example_advertiser_report_postback_urls.py
 #
-#  Copyright (c) 2014 TUNE, Inc.
+#  Copyright (c) 2015 TUNE, Inc.
 #  All rights reserved.
 #
 #  Permission is hereby granted, free of charge, to any person obtaining
@@ -30,10 +30,10 @@
 #  @category  Tune_Reporting
 #  @package   Tune_Reporting_Python
 #  @author    Jeff Tanner <jefft@tune.com>
-#  @copyright 2014 TUNE, Inc. (http://www.tune.com)
+#  @copyright 2015 TUNE, Inc. (http://www.tune.com)
 #  @license   http://opensource.org/licenses/MIT The MIT License (MIT)
-#  @version   $Date: 2014-12-31 17:01:21 $
-#  @link      https://developers.mobileapptracking.com/tune-reporting-sdks @endlink
+#  @version   $Date: 2015-01-05 19:38:53 $
+#  @link      https://developers.mobileapptracking.com @endlink
 #
 #  You can use the Logs report in the same way as the Actuals reports, but
 #  instead of being aggregated by request type, the Logs report contains the
@@ -76,21 +76,21 @@ class ExampleAdvertiserReportLogPostbacks(object):
     #
     # Example of running successful requests to TUNE Advertiser Report Log Postbacks.
     #
-    def run(self, api_key):
+    def run(self,
+            auth_key,
+            auth_type):
 
-        # api_key
-        if not api_key or len(api_key) < 1:
-            raise ValueError("Parameter 'api_key' is not defined.")
-
-        # Setup SDK Configuration with TUNE MobileAppTracking API Key.
+        # Setup TUNE Reporting SDK configuration.
         dirname = os.path.split(__file__)[0]
         dirname = os.path.dirname(dirname)
-        filepath = os.path.join(dirname, SdkConfig.SDK_CONFIG_FILENAME)
+        filepath = os.path.join(dirname, "config", SdkConfig.SDK_CONFIG_FILENAME)
 
         abspath = os.path.abspath(filepath)
 
         sdk_config = SdkConfig(filepath=abspath)
-        sdk_config.api_key = api_key
+        if auth_type and auth_key:
+            sdk_config.auth_key = auth_key
+            sdk_config.auth_type = auth_type
 
         print("")
         print("\033[34m" + "=================================================" + "\033[0m")
@@ -131,6 +131,9 @@ class ExampleAdvertiserReportLogPostbacks(object):
             print(" TuneManagementResponse:")
             print(str(response))
 
+            print(" JSON:")
+            print(response.json)
+
             print(" Count:")
             print(str(response.data))
 
@@ -186,9 +189,7 @@ class ExampleAdvertiserReportLogPostbacks(object):
             print("===========================================================")
 
             export_fetch_response = advertiser_report.fetch(
-                job_id,
-                verbose=True,
-                sleep=10
+                job_id
             )
 
             csv_report_url = AdvertiserReportLogPostbacks.parse_response_report_url(export_fetch_response)
@@ -224,6 +225,9 @@ class ExampleAdvertiserReportLogPostbacks(object):
             print(" TuneManagementResponse:")
             print(str(response))
 
+            print(" JSON:")
+            print(response.json)
+
             job_id = AdvertiserReportLogPostbacks.parse_response_report_job_id(response)
 
             print(" JSON Job ID: {}".format(job_id))
@@ -234,9 +238,7 @@ class ExampleAdvertiserReportLogPostbacks(object):
             print("===========================================================")
 
             export_fetch_response = advertiser_report.fetch(
-                job_id,
-                verbose=True,
-                sleep=10
+                job_id
             )
 
             print(" TuneManagementResponse:")
