@@ -3,7 +3,7 @@
 #
 #  test_advertiser_report_log_installs.py
 #
-#  Copyright (c) 2014 TUNE, Inc.
+#  Copyright (c) 2015 TUNE, Inc.
 #  All rights reserved.
 #
 #  Permission is hereby granted, free of charge, to any person obtaining
@@ -30,10 +30,10 @@
 #  @category  Tune_Reporting
 #  @package   Tune_Reporting_Python
 #  @author    Jeff Tanner <jefft@tune.com>
-#  @copyright 2014 TUNE, Inc. (http://www.tune.com)
+#  @copyright 2015 TUNE, Inc. (http://www.tune.com)
 #  @license   http://opensource.org/licenses/MIT The MIT License (MIT)
-#  @version   $Date: 2014-12-31 17:01:21 $
-#  @link      https://developers.mobileapptracking.com/tune-reporting-sdks @endlink
+#  @version   $Date: 2015-01-05 19:38:53 $
+#  @link      https://developers.mobileapptracking.com @endlink
 #
 
 import datetime
@@ -55,15 +55,15 @@ except ImportError as exc:
 class TestAdvertiserReportLogInstalls(unittest.TestCase):
 
     def __init__(self, api_key):
-        # Setup SDK Configuration with TUNE MobileAppTracking API Key.
+        # Setup TUNE Reporting SDK configuration.
         dirname = os.path.split(__file__)[0]
         dirname = os.path.dirname(dirname)
-        filepath = os.path.join(dirname, SdkConfig.SDK_CONFIG_FILENAME)
+        filepath = os.path.join(dirname, "config", SdkConfig.SDK_CONFIG_FILENAME)
 
         abspath = os.path.abspath(filepath)
 
         sdk_config = SdkConfig(filepath=abspath)
-        sdk_config.api_key = api_key
+        sdk_config.set_api_key(api_key)
         unittest.TestCase.__init__(self)
 
     def setUp(self):
@@ -73,7 +73,7 @@ class TestAdvertiserReportLogInstalls(unittest.TestCase):
 
     def test_ApiKey(self):
         sdk_config = SdkConfig()
-        api_key = sdk_config.api_key
+        api_key = sdk_config.auth_key
 
         self.assertIsNotNone(api_key)
         self.assertGreater(len(api_key), 0)
